<?php 

/**
* gutenblog functions and definitions
* @package gutenblog
*/

if( ! function_exists( 'gutenblog_theme_setup' ) )
{

function gutenblog_theme_setup() {
	
    load_theme_textdomain( 'gutenblog', get_template_directory() . '/lang' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	
	// Add default title support
	add_theme_support( 'title-tag' ); 		

	// Add default logo support		
    add_theme_support( 'custom-logo' );	

    // To use additional css
	add_editor_style( 'css/editor-style.css' );		
    
	add_theme_support('post-thumbnails');

    add_image_size('gutenblog-banner', 300, 200, true); 

	
	$defaults = array(
		'default-image'          => get_template_directory_uri() .'/assets/images/banner.jpg',
		'width'                  => 1920,
		'height'                 => 540,
		'uploads'                => true,
		'default-text-color'     => "80819f",
		'wp-head-callback'       => 'gutenblog_header_style',
	);
	add_theme_support( 'custom-header', $defaults );

	/**
	* Set the content width in pixels, based on the theme's design and stylesheet.
	*/
	$GLOBALS['content_width'] = apply_filters( 'gutenblog_content_width', 980 );
	
	// Add theme support for Semantic Markup
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption'
	) );
	 
	 add_theme_support( 'customize-selective-refresh-widgets' );
	 
	// add excerpt support for pages
	add_post_type_support( 'page', 'excerpt' );
	
	if ( is_singular() && comments_open() ) {
		wp_enqueue_script( 'comment-reply' );
	}
   

    register_nav_menus(array(
   'primary' => esc_html__('primary Menu', 'gutenblog')
   ));	


}
add_action( 'after_setup_theme', 'gutenblog_theme_setup' );
}



if ( ! function_exists( 'gutenblog_single_post_navigation' ) ) :
/**
 * Displays an optional single post navigation
 *
 *
 * Create your own gutenblog_post_navigation() function to override in a child theme.
 *
 * @since Create Magazine 1.0
 */
function gutenblog_single_post_navigation() {

   

    the_post_navigation( array(
        'prev_text' => '<span class="fa fa-angle-left"></span>'.esc_html__( ' Previous Article','gutenblog' ),
        'next_text' => esc_html__( 'Next Article','gutenblog' ).' <span class="fa fa-angle-right"></span>'
    ) );
}
endif;





function gutenblog_header_style()
{
		$gutenblog_header_text_color = get_header_textcolor();

	?>
		<style type="text/css">
			<?php
				//Check if user has defined any header image.
				if ( get_header_image() ) :
			?>

			.blogtitle
			         {
					color: #<?php echo esc_attr($gutenblog_header_text_color); ?>;
					
				     }
				.pageTitle
                    {
                            background-image:url('<?php header_image(); ?>');
                    }
		
				}
			<?php endif; ?>	
		</style>
	<?php

}
 require get_template_directory() .	'/inc/customizer.php';
require get_template_directory(). '/class-wp-bootstrap-navwalker.php';



	if( ! function_exists( 'gutenblog_enqueue_styles' ) ) {
	function gutenblog_enqueue_styles() {
		
	// Bootstrap CSS 
	wp_enqueue_style('gutenblog-font', 'https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,700,800|Playfair+Display:400,400i,700,700i,900');

	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', array(), '', 'all');
	wp_enqueue_style('ionicons', get_template_directory_uri() . '/assets/css/ionicons.css', array(), '', 'all');
	wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.css', array(), '', 'all');
    wp_enqueue_style('owl-theme-default', get_template_directory_uri() . '/assets/css/owl.theme.default.css', array(), '', 'all');

	wp_enqueue_style('gutenblog-style', get_stylesheet_uri() );

	}
	add_action( 'wp_enqueue_scripts', 'gutenblog_enqueue_styles' );
	}

	/**
	* Enqueue JS scripts

	*/

if( ! function_exists( 'gutenblog_enqueue_scripts' ) ) {
	function gutenblog_enqueue_scripts() {   
	  wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js',array('jquery'),'', true);
      wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array(), '', true);
      wp_enqueue_script('jquery-sticky', get_template_directory_uri() . '/assets/js/jquery.sticky.js', array(), '', true);
	  wp_enqueue_script('isotope-pkgd', get_template_directory_uri() . '/assets/js/isotope.pkgd.js',array(),'', true);
	  wp_enqueue_script('gutenblog-custome-js', get_template_directory_uri() . '/assets/js/custome.js',array(),'', true);
	  wp_enqueue_script('gutenblog-escritor', get_template_directory_uri() . '/assets/js/escritor.js',array(),'', true);
	
	}
	add_action( 'wp_enqueue_scripts', 'gutenblog_enqueue_scripts' );	
}


function gutenblog_sidebars() {

	// Blog Sidebar

	register_sidebar(array(
		'name' => esc_html__( 'Blog Sidebar', "gutenblog"),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar on the blog layout.', "gutenblog"),
		'before_widget' => '<div id=""%1$s" class="widget popularPostWidget styleThree u-whiteBg u-shadow-0x0x5--05 %2$s clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgetTitle textDark  text-center">',
		'after_title' => '</h4>',
	));	
		
}
add_action( 'widgets_init', 'gutenblog_sidebars' );




function gutenblog_custom_excerpt_length( $length ) {
        return 30;
		}
		add_filter( 'excerpt_length', 'gutenblog_custom_excerpt_length', 999 );
function gutenblog_placeholders( $fields )
{
    $fields['author'] = str_replace(
        '<input',
        '<input placeholder="'
            . _x(
                'Your Name',
                'comment form placeholder',
                'gutenblog'
                )
            . '"',
        $fields['author']
    );
    $fields['email'] = str_replace(
        '<input',
        '<input placeholder="'
            . _x(
                'Your Email',
                'comment form placeholder',
                'gutenblog'
                )
            . '"',
        $fields['email']
    );



    return $fields;
}

add_filter( 'comment_form_default_fields', 'gutenblog_placeholders' );


/* Add Placehoder in comment Form Field (Comment) */
add_filter( 'comment_form_defaults', 'gutenblog_textarea_placeholder' );
 
function gutenblog_textarea_placeholder( $fields )
{
    $fields['comment_field'] = str_replace(
    '<textarea',
    '<textarea placeholder="'
    . esc_attr__('Type Your comment....','gutenblog').'"',
    $fields['comment_field']
    );
   
 
    return $fields;
}
function gutenblog_comment_reform ($arg) {
$arg['title_reply'] = esc_html__('Leave a Response','gutenblog');
return $arg;
}
add_filter('comment_form_defaults','gutenblog_comment_reform');