<?php
/**
* gutenblog customizer
* @package gutenblog
*/

if ( !function_exists('gutenblog_customizer_register') ) :

    function gutenblog_customizer_register ( $wp_customize ) {
        
        // Add Class Drop Down Taxonomy
        class gutenblog_Dropdown_Taxonomies_Control extends WP_Customize_Control {

            /**
             * Control type.
             *
             * @access public
             * @var string
             */
            public $type = 'dropdown-taxonomies';

            /**
             * Taxonomy.
             *
             * @access public
             * @var string
             */
            public $taxonomy = '';

            public function __construct( $manager, $id, $args = array() ) {

                $our_taxonomy = 'category';
                if ( isset( $args['taxonomy'] ) ) {
                    $taxonomy_exist = taxonomy_exists( $args['taxonomy']  );
                    if ( true === $taxonomy_exist ) {
                        $our_taxonomy =  $args['taxonomy'];
                    }
                }
                $args['taxonomy'] = $our_taxonomy;
                $this->taxonomy =  $our_taxonomy;

                parent::__construct( $manager, $id, $args );
            }

            /**
             * Render content.
             *
             * @since 1.0.0
             */
            public function render_content() {

                $tax_args = array(
                    'hierarchical' => 0,
                    'taxonomy'     => $this->taxonomy,
                );
                $all_taxonomies = get_categories( $tax_args );

                ?>
                <label>
                    <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                    <select <?php $this->link(); ?>>
                        <?php
                        printf( '<option value="%s" %s>%s</option>', 
                            0, 
                            selected( $this->value(), 
                                '', 
                                false 
                            ), 
                            esc_html__( 'All', 'gutenblog' )  
                        );
                        ?>
                        <?php if ( ! empty( $all_taxonomies ) ) :  ?>
                            <?php foreach ( $all_taxonomies as $key => $tax ) :  ?>
                                <?php
                                printf( '<option value="%s" %s>%s</option>', esc_attr( $tax->term_id ), selected( $this->value(), $tax->term_id, false ), esc_html( $tax->name ) );
                                ?>
                            <?php endforeach ?>
                        <?php endif ?>
                    </select>
                </label>
                <?php
            }
        } 

        // Function For enable/disable Section
        if ( !function_exists('section_option') ) :
            function section_option () {
                $section_option = array(
                    'on' => esc_html__('Show', 'gutenblog'),
                    'off' => esc_html__('Hide', 'gutenblog')
                );
                return apply_filters('section_option', $section_option);
            }
        endif;
              

            
        /* Sanitization */
        if ( !function_exists('sanitize_select') ) :
            function sanitize_select( $input, $setting ) {

                // Ensure input is a slug.
                $input = sanitize_text_field( $input );

                // Get list of choices from the control associated with the setting.
                $choices = $setting->manager->get_control( $setting->id )->choices;

                // If the input is a valid key, return it; otherwise, return the default.
                return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
            }
        endif;


        function sanitize_dropdown_pages( $page_id, $setting ) {
            // Ensure $input is an absolute integer.
            $page_id = absint( $page_id );
            
            // If $page_id is an ID of a published page, return it; otherwise, return the default.
            return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
        }

        /** Front Page Setting  **/
        $wp_customize->add_panel('frontpage', 
            array('title' => esc_html__('Gutenblog Sections Setting', 'gutenblog'),
            'description' => '',
            'priority' => 1,)
        );

        // Add Header Bar Section

        /** Start Header Search **/
        $wp_customize->add_section('gutenblog_header_bar_search', array(
            'title'   => esc_html__('Menu Bar Search', 'gutenblog'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 99
        ));

        $wp_customize->add_setting(
            'header_search_button_onoff',
            array(
                'default'           => 'off',
                'sanitize_callback' => 'sanitize_select',
            )
        );

        $gutenblog_header_onoff = section_option();

        $wp_customize->add_control(
            'header_search_button_onoff',
            array(
                'type' => 'radio',
                'label' => esc_html__('Menu Bar Search', 'gutenblog'),
                'description' => esc_html__('on/off option for Menu Bar Search.', 'gutenblog'),
                'section' => 'gutenblog_header_bar_search',
                'choices' => $gutenblog_header_onoff,
                'priority' => 1
            )
        );

        
        // Add Slider Section
        /** Start Slider Section **/
        $wp_customize->add_section('gutenblog_slider', array(
            'title'   => esc_html__('Featured', 'gutenblog'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 120
        ));

        $wp_customize->add_setting(
            'slider_onoff',
            array(
                'default' => 'off',
                'sanitize_callback' => 'sanitize_select',
            )
        );

        $gutenblog_slider_onoff = section_option();

        $wp_customize->add_control(
            'slider_onoff',
            array(
                'type' => 'radio',
                'label' => esc_html__('Featured Section', 'gutenblog'),
                'description' => esc_html__('Show/hide option for Featured Section.', 'gutenblog'),
                'section' => 'gutenblog_slider',
                'choices' => $gutenblog_slider_onoff,
                'priority' => 1
            )
        );
        $gutenblog_slide_category             =   'slide_category';
        $gutenblog_slide_posts                =   'slide_posts';
        $gutenblog_slide_category_label       =   esc_html__('Select Category For Featured Section', 'gutenblog');
        $gutenblog_slide_posts_label          =   esc_html__('Number of Posts for Featured Section', 'gutenblog');

        //  Slider Image    
        $wp_customize->add_setting( $gutenblog_slide_category, array(

            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'absint',
        ) );
        
        $wp_customize->add_control( new gutenblog_Dropdown_Taxonomies_Control( $wp_customize, $gutenblog_slide_category, array(
                'label'    => $gutenblog_slide_category_label,
                'section'  => 'gutenblog_slider',
                'type'     => 'dropdown-taxonomies',
                'taxonomy' => 'category',
                'priority' => 2,
            )
        ) );

        $wp_customize->add_setting( $gutenblog_slide_posts, array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        
        $wp_customize->add_control( $gutenblog_slide_posts, array(

            'label'             => $gutenblog_slide_posts_label,
            'section'           => 'gutenblog_slider',
            'type'              => 'text',
            'priority'          => 3,
        ));

       $wp_customize->add_setting('gutenblog_feature_title', 
         array(
            'default'            => '',
            'type'               => 'theme_mod',
            'sanitize_callback'  => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('gutenblog_feature_title', 
        array(
            'label'    => esc_html__('Feature Title', 'gutenblog'),
            'section'  => 'gutenblog_slider',
            'priority' => 1
        )
    );

      $wp_customize->add_setting('gutenblog_feature_subtitle', 
         array(
            'default'            => '',
            'type'               => 'theme_mod',
            'sanitize_callback'  => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('gutenblog_feature_subtitle', 
        array(
            'label'    => esc_html__('Feature Sub Title', 'gutenblog'),
            'section'  => 'gutenblog_slider',
            'priority' => 1
        )
    );

        // Add Footer Section
        /** Start Footer Section **/
        $wp_customize->add_section('gutenblog_footer', array(
            'title'   => esc_html__('Footer Section', 'gutenblog'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 170
        ));

        $wp_customize->add_setting(
            'footer_button_onoff',
            array(
                'default' => 'off',
                'sanitize_callback' => 'sanitize_select',
            )
        );

        $gutenblog_footer_onoff = section_option();

        $wp_customize->add_control(
            'footer_button_onoff',
            array(
                'type' => 'radio',
                'label' => esc_html__('Footer Section', 'gutenblog'),
                'description' => esc_html__('show/hide option for Footer Section.', 'gutenblog'),
                'section' => 'gutenblog_footer',
                'choices' => $gutenblog_footer_onoff,
                'priority' => 3
            )
        );


        // Footer Copyright
       $wp_customize->add_setting('gutenblog_footer_copyright',
         array(
            'default'             => '',
            'type'                => 'theme_mod',
            'sanitize_callback'   => 'wp_kses_post'
        )
    );

    $wp_customize->add_control('gutenblog_footer_copyright',
         array(
            'label'    => esc_html__('Copyright', 'gutenblog'),
            'section'  => 'gutenblog_footer',
            'type'     => 'textarea',
            'priority' => 3
    ));


        //top footer//

$wp_customize->add_section('gutenblog_top_footer', array(
            'title'   => esc_html__('Top Footer Section', 'gutenblog'),
            'description' => '',
            'panel' => 'frontpage',
            'priority'    => 160
        ));

        $wp_customize->add_setting(
            'top_footer_button_onoff',
            array(
                'default' => 'off',
                'sanitize_callback' => 'sanitize_select',
            )
        );



        $gutenblog_top_footer_onoff = section_option();

        $wp_customize->add_control(
            'top_footer_button_onoff',
            array(
                'type' => 'radio',
                'label' => esc_html__('Footer Section', 'gutenblog'),
                'description' => esc_html__('show/hide option for Footer Section.', 'gutenblog'),
                'section' => 'gutenblog_top_footer',
                'choices' => $gutenblog_top_footer_onoff,
                'priority' => 2
            )
        );


        // Footer Copyright
        $wp_customize->add_setting('footer_text', array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        ));

        $wp_customize->add_control('footer_text', array(
            'label'   => esc_html__('Footer Text', 'gutenblog'),
            'section' => 'gutenblog_top_footer',
            'type' => 'text',
            'priority'  => 3
        ));

    }
endif;
add_action( 'customize_register', 'gutenblog_customizer_register' );